parse_note_meta

Function parse_note_meta 

pub fn parse_note_meta(content: &str) -> (Option<NoteMeta>, String)
Parse Oxios frontmatter from a note’s content.

Returns (Some(NoteMeta), body) if the oxios: key is present in the frontmatter. Returns (None, original_content) if there is no frontmatter or the frontmatter does not contain the oxios: key (e.g., user-written Obsidian frontmatter). In the latter case, the full original content (including any user frontmatter) is returned as the body.